@@ -9,6 +9,8 @@
 #![deny(missing_docs)]
 #![allow(clippy::needless_return)]
 
+use std::fmt;
+
 use num_complex::Complex;
 use num_traits::{PrimInt, Signed};
 
@@ -39,8 +41,18 @@ impl<T: PrimInt + Signed> GaussianInt<T> {
     }
 
     /// Returns the norm.
-    pub fn norm(self) -> Self {
-        self * self.conj()
+    pub fn norm(&self) -> Self {
+        *self * self.conj()
+    }
+
+    /// Returns `true` if `self` is a divisor of `other`.
+    pub fn is_divisor_of(&self, other: Self) -> bool {
+        (other % *self) == Self::zero() && !(other.0.re != T::zero() && other.0.im != T::zero())
+    }
+
+    /// Tests whether a Gaussian integer is a rational integer.
+    pub fn is_rational(&self) -> bool {
+        self.0.im == T::zero()
     }
 
     /// Tests for [Gaussian primality].
@@ -86,13 +98,50 @@ impl<T: PrimInt + Signed> GaussianInt<T> {
 
         condition_1 || condition_2
     }
+}
 
-    /// Tests whether a Gaussian integer is a rational integer.
-    pub fn is_rational(&self) -> bool {
-        self.0.im == T::zero()
+impl<T: PrimInt + Signed> GaussianInt<T>
+where
+    f64: From<T>,
+{
+    /// Converts to polar form (r, theta).
+    pub fn to_polar(&self) -> (f64, f64) {
+        let a = self.0.re;
+        let b = self.0.im;
+        let a: f64 = a.into();
+        let b: f64 = b.into();
+        Complex::new(a, b).to_polar()
     }
 }
 
+/// Returns an iterator of all Gaussian primes with positive real parts
+/// and with integer parts below *n*.
+pub fn get_positive_primes(n: isize) -> impl Iterator<Item = GaussianInt<isize>> + 'static {
+    let mut primes: Vec<GaussianInt<_>> = vec![];
+    for a in 0..=n {
+        for b in 0..=n {
+            let z = GaussianInt::new(a, b);
+            if z.is_gaussian_prime() {
+                primes.push(z);
+            }
+        }
+    }
+    primes.into_iter()
+}
+
+/// Returns an iterator of all Gaussian integers with positive real parts
+/// and with integer parts below *n*.
+pub fn get_g_ints(n: isize) -> impl Iterator<Item = GaussianInt<isize>> + 'static {
+    let mut primes: Vec<GaussianInt<_>> = vec![];
+    for a in 0..=n {
+        for b in -n..=n {
+            let z = GaussianInt::new(a, b);
+            primes.push(z);
+        }
+    }
+    primes.into_iter()
+}
+
 impl<T: PrimInt> From<Complex<T>> for GaussianInt<T> {
     fn from(g: Complex<T>) -> Self {
         Self(g)
@@ -120,5 +169,26 @@ fn is_prime(number: i32) -> bool {
     return number > 1;
 }
 
+impl<T: PrimInt> fmt::Display for GaussianInt<T> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let zero = T::zero();
+        if self.0.im < zero {
+            write!(
+                f,
+                "{}{}i",
+                self.0.re.to_isize().unwrap(),
+                self.0.im.to_isize().unwrap()
+            )
+        } else {
+            write!(
+                f,
+                "{}+{}i",
+                self.0.re.to_isize().unwrap(),
+                self.0.im.to_isize().unwrap()
+            )
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests;
