@@ -81,6 +81,23 @@ mod tests {
         assert!(c1 % c2 != GaussianInt::zero());
     }
 
+    #[test]
+    fn neg() {
+        let z = GaussianInt::new(2, 2);
+        assert_eq!(z + -z, GaussianInt::zero());
+    }
+
+    #[test]
+    fn is_divisor_of() {
+        let five = GaussianInt::new(5, 0);
+        assert!(GaussianInt::new(1, 0).is_divisor_of(five));
+        assert!(GaussianInt::new(1, 2).is_divisor_of(five));
+        assert!(GaussianInt::new(1, -2).is_divisor_of(five));
+        assert!(GaussianInt::new(2, 1).is_divisor_of(five));
+        assert!(GaussianInt::new(2, -1).is_divisor_of(five));
+        assert!(five.is_divisor_of(five));
+    }
+
     #[test]
     fn from_i32() {
         let c = GaussianInt::new(5, 0);
@@ -126,4 +143,14 @@ mod tests {
         let c = GaussianInt::new(5, 1);
         assert!(!c.is_rational());
     }
+
+    #[test]
+    fn to_polar() {
+        let c = GaussianInt::new(5, 0);
+        assert_eq!(c.to_polar(), (5f64, 0f64));
+        let c = GaussianInt::new(0, 1);
+        assert_eq!(c.to_polar(), (1f64, std::f64::consts::PI / 2f64));
+        let c = GaussianInt::new(0, -1);
+        assert_eq!(c.to_polar(), (1f64, -std::f64::consts::PI / 2f64));
+    }
 }
